from distutils.core import setup
setup (
name = 'kaihau',
version='1.0.0',
author = 'yfx',
author_email='2573179560@qq.com',
# py_modules = 'my_module',
url="https://pypi.org/"
# py_modules = ['my_module'],
)